@@ -125,8 +125,8 @@ PROMPT:
 
     chomp $response;
 
-    return $response if $response; # if they typed something, return it
-    return $default if $default;   # return the default, if available
+    return $response if defined $response; # if they typed something, return it
+    return $default if defined $default;   # return the default, if available
     return '';                     # return empty handed
 }
 
@@ -2305,7 +2305,7 @@ Provision::Unix::Utility - utility subroutines for sysadmin tasks
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 SYNOPSIS
 
