@@ -4,9 +4,8 @@ package Provision::Unix::Web::Apache;
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
-use Carp;
 use English qw( -no_match_vars );
 use Params::Validate qw( :all );
 
@@ -184,8 +183,8 @@ sub conf_get_dir {
         );
 
         unless ( -x $apachectl ) {
-            croak
-                "apache->conf_get_dir: failed to find apachectl!  Is Apache installed correctly?\n";
+            die "apache->conf_get_dir: failed to find apachectl!
+        Is Apache installed correctly?\n";
         }
     }
 
@@ -440,7 +439,7 @@ sub destroy {
 
     print "Dropping: \n" . join( "\n", @$drop ) . "\n";
 
-    if ( length @$new == 0 || length @$drop == 0 ) {
+    if ( scalar @$new == 0 || scalar @$drop == 0 ) {
         return {
             error_code => 500,
             error_desc => "yikes, something went horribly wrong!"
@@ -691,7 +690,7 @@ Provision::Unix::Web::Apache - provision web hosting accounts on Apache
 
 =head1 VERSION
 
-version 1.02
+version 1.04
 
 =head1 SYNOPSIS
 
